==> docker-client-6.2.3-sources.jar: com/spotify/docker/client/messages/ContainerMount.java <==
/*-
 * -\-\-
 * docker-client
 * --
 * Copyright (C) 2016 Spotify AB
 * --
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * -/-/-
 */

package com.spotify.docker.client.messages;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.ANY;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.base.MoreObjects;

import java.util.Objects;

@JsonAutoDetect(fieldVisibility = ANY, getterVisibility = NONE, setterVisibility = NONE)
public class ContainerMount {

  @JsonProperty("Source")
  private String source;
  @JsonProperty("Destination")
  private String destination;
  @JsonProperty("Mode")
  private String mode;
  @JsonProperty("RW")
  private Boolean rw;

  public String source() {
    return source;
  }

  public String destination() {
    return destination;
  }

  public String mode() {
    return mode;
  }

  public Boolean rw() {
    return rw;
  }

  @Override
  public boolean equals(final Object obj) {
    if (this == obj) {
      return true;
    }
    if (obj == null || getClass() != obj.getClass()) {
      return false;
    }

    final ContainerMount that = (ContainerMount) obj;

    return Objects.equals(this.source, that.source)
           && Objects.equals(this.destination, that.destination)
           && Objects.equals(this.mode, that.mode)
           && Objects.equals(this.rw, that.rw);
  }

  @Override
  public int hashCode() {
    return Objects.hash(source, destination, mode, rw);
  }

  @Override
  public String toString() {
    return MoreObjects.toStringHelper(this)
        .add("source", source)
        .add("destination", destination)
        .add("mode", mode)
        .add("rw", rw)
        .toString();
  }
}

==> docker-client-8.3.2-sources.jar: com/spotify/docker/client/messages/ContainerMount.java <==
/*-
 * -\-\-
 * docker-client
 * --
 * Copyright (C) 2016 Spotify AB
 * --
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * -/-/-
 */

package com.spotify.docker.client.messages;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.ANY;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.auto.value.AutoValue;


@AutoValue
@JsonAutoDetect(fieldVisibility = ANY, getterVisibility = NONE, setterVisibility = NONE)
public abstract class ContainerMount {

  @JsonProperty("Source")
  public abstract String source();

  @JsonProperty("Destination")
  public abstract String destination();

  @JsonProperty("Mode")
  public abstract String mode();

  @JsonProperty("RW")
  public abstract Boolean rw();

  @JsonCreator
  static ContainerMount create(
      @JsonProperty("Source") final String source,
      @JsonProperty("Destination") final String destination,
      @JsonProperty("Mode") final String mode,
      @JsonProperty("RW") final Boolean rw) {
    return new AutoValue_ContainerMount(source, destination, mode, rw);
  }
}
